@@ -149,7 +149,7 @@
 #' R package version 0.2.10.
 #'
 #' @importFrom ggplot2 theme element_blank element_line element_text
-#' ggplot aes_ geom_line geom_point scale_color_manual
+#' ggplot aes geom_line geom_point scale_color_manual
 #' scale_x_continuous scale_y_continuous
 #' @importFrom gee gee
 #' @importFrom geepack genZcor geese
@@ -163,7 +163,7 @@ GEE <- function(formula,family,data,coord,
               corstr="fixed",cluster=3,moran.params=list(),
               plot=FALSE,scale.fix=FALSE, customize_plot = NULL){
 
-  if(!is.null(customize_plot) | plot) {
+  if(!is.null(customize_plot) & plot) {
     warning('"customize_plot" and "plot = TRUE" arguments are now soft deprecated.\n',
             'Use plot.GEE method and access the ggplot2 object using object_name$plot\n',
             'subsequent modification.')
